@@ -4,7 +4,7 @@ from openhasp_config_manager.cli.common import _create_config_manager, _analyze_
 from openhasp_config_manager.ui.util import success, error
 
 
-def c_cmd(config_dir: Path, device: str, command: str, payload: str):
+async def c_cmd(config_dir: Path, device: str, command: str, payload: str):
     try:
         config_manager = _create_config_manager(config_dir, Path("./nonexistent"))
         filtered_devices, ignored_devices = _analyze_and_filter(config_manager=config_manager, device_filter=device)
@@ -13,7 +13,7 @@ def c_cmd(config_dir: Path, device: str, command: str, payload: str):
             raise Exception(f"No device matches the filter: {device}")
 
         for device in filtered_devices:
-            _cmd(device, command, payload)
+            await _cmd(device, command, payload)
         success("Done!")
     except Exception as ex:
         error(str(ex))
